pub fn enqueue(
queue: &mut CommandQueue,
label: &str,
priority: CommandPriority,
) -> u64Expand description
Enqueue a single command with the given label and priority. Returns the assigned command id.
pub fn enqueue(
queue: &mut CommandQueue,
label: &str,
priority: CommandPriority,
) -> u64Enqueue a single command with the given label and priority. Returns the assigned command id.