pub fn has_priority(queue: &CommandQueue, priority: &CommandPriority) -> boolExpand description
Return true if there is at least one command of the given priority.
pub fn has_priority(queue: &CommandQueue, priority: &CommandPriority) -> boolReturn true if there is at least one command of the given priority.