pub enum B64sDecodeError {
InvalidCharacter {
byte: u8,
position: usize,
},
InvalidPadding,
InvalidLength {
length: usize,
},
}Expand description
Specific reason a base64 decode failed.
Variants
InvalidCharacter
Encountered a byte that is not part of the chosen alphabet, not padding, and not whitespace.
Fields
InvalidPadding
Padding characters appear at an unexpected position.
InvalidLength
After stripping whitespace, the remaining length is not valid
(i.e. len % 4 == 1 which can never be produced by encoding).