pub fn execute_command(
bus: &mut CommandBus,
cmd: Box<dyn Command>,
) -> CommandResultExpand description
Execute a command and push it onto the undo stack. Clears the redo stack (standard undo/redo semantics).
pub fn execute_command(
bus: &mut CommandBus,
cmd: Box<dyn Command>,
) -> CommandResultExecute a command and push it onto the undo stack. Clears the redo stack (standard undo/redo semantics).