pub struct PackVerifyReport {
pub total_files: usize,
pub ok_files: usize,
pub failed_files: Vec<String>,
pub missing_files: Vec<String>,
pub is_valid: bool,
}Expand description
The result of verifying a pack directory against a set of FileRecords.
Fields
total_files: usizeok_files: usizefailed_files: Vec<String>Files that existed but had a wrong hash or size.
missing_files: Vec<String>Files listed in records but not found on disk.
is_valid: boolImplementations