PersistentHashMap

Struct PersistentHashMap 

pub struct PersistentHashMap<K, V> { /* private fields */ }
Persistent hash map that keeps all historical versions.

Implementations

Source

impl<K, V> PersistentHashMap<K, V>
where K: Eq + Hash + Clone, V: Clone,

pub fn new() -> Self

Create a persistent map with an empty initial version.

pub fn current_version(&self) -> PmapVersion

Current (latest) version number.

pub fn insert(&mut self, key: K, value: V) -> PmapVersion

Insert keyvalue into the current version, producing a new version.

pub fn remove(&mut self, key: &K) -> PmapVersion

Remove key from the current version, producing a new version.

pub fn get_at(&self, version: PmapVersion, key: &K) -> Option<&V>

Get a value at a specific version.

pub fn get(&self, key: &K) -> Option<&V>

Get a value at the current version.

pub fn len(&self) -> usize

Number of entries in the current version.

pub fn is_empty(&self) -> bool

True if the current version is empty.

pub fn version_count(&self) -> usize

Total versions stored.