pub struct FingerTree<T> { /* private fields */ }Expand description
A finger tree sequence.
Implementations
Sourceimpl<T: Clone> FingerTree<T>
impl<T: Clone> FingerTree<T>
Sourcepub fn push_right(&mut self, value: T)
pub fn push_right(&mut self, value: T)
Push an element onto the right (back).
Sourcepub fn peek_right(&self) -> Option<&T>
pub fn peek_right(&self) -> Option<&T>
Peek at the rightmost element.
Sourcepub fn concat(&mut self, other: FingerTree<T>)
pub fn concat(&mut self, other: FingerTree<T>)
Concatenate another finger tree onto the right of this one.
Sourcepub fn split_at(&mut self, at: usize) -> FingerTree<T>
pub fn split_at(&mut self, at: usize) -> FingerTree<T>
Split the tree at index at, returning the right portion.